local _, telescope = pcall(require, "telescope")
local ok, builtin = pcall(require, "telescope.builtin")
if not ok then
    return
end

local nmap = require("my.utils").nmap

telescope.setup {
    extensions = {
        fzf = {
            fuzzy = true,
            override_generic_sorter = true,
            override_file_sorter = true,
            case_mode = "smart_case",
        }
    }
}

local function project()
    local exclusions = {
        "**/.git/",
        "*.svg",
        "*.png",
        "*.jpg",
    }

    local find_command = nil
    if FD_EXISTS == 1 then
        find_command = { "fd", "--hidden", "-t", "f" }
        for _, value in ipairs(exclusions) do
            table.insert(find_command, "--exclude")
            table.insert(find_command, value)
        end
    elseif RIPGREP_EXISTS == 1 then
        find_command = { "rg", "--files", "--hidden", "--glob", "!**/.git/*" }
    end

    builtin.find_files {
        find_command = find_command,
    }
end

local function dotfiles()
    builtin.git_files {
        shorten_path = true,
        prompt_title = " ~ dotfiles ~ ",
        cwd = vim.env.DOTFILES_DIRECTORY,
    }
end

nmap("<C-p>", project, "Find project files")
nmap("<Leader>fn", dotfiles, "Dotfiles")
nmap("<Leader><C-p>", builtin.git_files, "Find git files")
nmap("<Leader>fg", builtin.live_grep, "Live grep")
nmap("<Leader>gs", builtin.git_status, "Git status")

telescope.load_extension("fzf")
